Class: Blockchain0x::Webhooks::Result
- Inherits:
-
Struct
- Object
- Struct
- Blockchain0x::Webhooks::Result
- Defined in:
- lib/blockchain0x/webhooks.rb
Overview
Result returned by ‘verify`. Use `result.ok?` to branch.
On success, ‘event_type`, `event_id`, `delivery_id` are populated (may be nil if the framework dropped the header but the signature verified).
On failure, ‘code` is one of the constants above and the event-detail fields are nil.
Instance Attribute Summary collapse
-
#code ⇒ Object
Returns the value of attribute code.
-
#delivery_id ⇒ Object
Returns the value of attribute delivery_id.
-
#event_id ⇒ Object
Returns the value of attribute event_id.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#ok ⇒ Object
Returns the value of attribute ok.
Instance Method Summary collapse
Instance Attribute Details
#code ⇒ Object
Returns the value of attribute code
63 64 65 |
# File 'lib/blockchain0x/webhooks.rb', line 63 def code @code end |
#delivery_id ⇒ Object
Returns the value of attribute delivery_id
63 64 65 |
# File 'lib/blockchain0x/webhooks.rb', line 63 def delivery_id @delivery_id end |
#event_id ⇒ Object
Returns the value of attribute event_id
63 64 65 |
# File 'lib/blockchain0x/webhooks.rb', line 63 def event_id @event_id end |
#event_type ⇒ Object
Returns the value of attribute event_type
63 64 65 |
# File 'lib/blockchain0x/webhooks.rb', line 63 def event_type @event_type end |
#ok ⇒ Object
Returns the value of attribute ok
63 64 65 |
# File 'lib/blockchain0x/webhooks.rb', line 63 def ok @ok end |
Instance Method Details
#ok? ⇒ Boolean
64 65 66 |
# File 'lib/blockchain0x/webhooks.rb', line 64 def ok? ok == true end |